@@ -5,8 +5,8 @@ sys.path.insert(0, os.path.abspath('.'))
 # The version of the library
 try:
     ### The main function to be used to read the files
-    from file_reader import set_book_config
-    from file_reader import set_library_config
+    from config import set_chapter_config
+    from config import set_book_config
     # Some additional interesting functions
     from render_true_or_false import true_or_false
     from render_to_do_list import to_do_list
@@ -18,8 +18,8 @@ try:
     from social_media import share
 except:
     ### The main function to be used to read the files
-    from .file_reader import set_book_config
-    from .file_reader import set_library_config
+    from .config import set_chapter_config
+    from .config import set_book_config
     # Some additional interesting functions
     from .render_true_or_false import true_or_false
     from .render_to_do_list import to_do_list
